/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package datareq

import (
	"github.com/apache/trafficcontrol/v8/traffic_monitor/health"

	"github.com/json-iterator/go"
)

// JSONEvents represents the structure we wish to serialize to JSON, for Events.
type JSONEvents struct {
	Events []health.Event `json:"events"`
}

func srvEventLog(events health.ThreadsafeEvents) ([]byte, error) {
	json := jsoniter.ConfigFastest
	return json.Marshal(JSONEvents{Events: events.Get()})
}
